==> amplify_authenticator-0.2.3.tar.gz: lib/src/state/auth_state.dart <==
/*
 * Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

import 'package:amplify_auth_cognito/amplify_auth_cognito.dart';
import 'package:amplify_authenticator/src/enums/authenticator_step.dart';
import 'package:flutter/foundation.dart';

abstract class AuthState {
  const AuthState();
}

class LoadingState extends AuthState {
  const LoadingState();

  AuthenticatorStep get step => AuthenticatorStep.loading;
}

class AuthenticatedState extends AuthState {
  const AuthenticatedState();
}

@immutable
class UnauthenticatedState extends AuthState {
  final AuthenticatorStep _step;
  const UnauthenticatedState({required AuthenticatorStep step}) : _step = step;

  AuthenticatorStep get step => _step;

  static const signUp = UnauthenticatedState(step: AuthenticatorStep.signUp);
  static const signIn = UnauthenticatedState(step: AuthenticatorStep.signIn);
  static const confirmSignUp =
      UnauthenticatedState(step: AuthenticatorStep.confirmSignUp);
  static const confirmSignInMfa =
      UnauthenticatedState(step: AuthenticatorStep.confirmSignInMfa);
  static const confirmSignInNewPassword =
      UnauthenticatedState(step: AuthenticatorStep.confirmSignInNewPassword);
  static const resetPassword =
      UnauthenticatedState(step: AuthenticatorStep.resetPassword);
  static const confirmResetPassword =
      UnauthenticatedState(step: AuthenticatorStep.confirmResetPassword);
  static const verifyUser =
      UnauthenticatedState(step: AuthenticatorStep.verifyUser);

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is UnauthenticatedState && other.step == step;

  @override
  int get hashCode => step.hashCode;
}

class AttributeVerificationSent extends UnauthenticatedState {
  const AttributeVerificationSent(this.userAttributeKey)
      : super(step: AuthenticatorStep.confirmVerifyUser);

  final CognitoUserAttributeKey userAttributeKey;
}

class VerifyUserFlow extends UnauthenticatedState {
  final List<CognitoUserAttributeKey> unverifiedAttributeKeys;

  const VerifyUserFlow({required this.unverifiedAttributeKeys})
      : super(step: AuthenticatorStep.verifyUser);
}

class ConfirmSignInCustom extends UnauthenticatedState {
  final Map<String, String> publicParameters;

  const ConfirmSignInCustom({
    this.publicParameters = const <String, String>{},
  }) : super(step: AuthenticatorStep.confirmSignInCustomAuth);
}

/// A state that indicates that there is a check to
/// determine the user's verification state in progress.
///
/// This indicates that either Sign In OR Confirm Sign In
/// has completed, but it is currently unknown if the user needs
/// to be taken to the `veryUser` step or to an authenticated state
/// because the call to fetch user attributes is pending.
class PendingVerificationCheckState extends UnauthenticatedState {
  const PendingVerificationCheckState({
    required AuthenticatorStep step,
  })  : assert(
          step == AuthenticatorStep.signIn ||
              step == AuthenticatorStep.confirmSignUp,
          'Invalid AuthenticatorStep type: $step',
        ),
        super(step: step);
}

==> amplify_authenticator-1.3.2.tar.gz: lib/src/state/auth_state.dart <==
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0

import 'package:amplify_authenticator/src/enums/authenticator_step.dart';
import 'package:amplify_flutter/amplify_flutter.dart';
import 'package:flutter/foundation.dart';

abstract class AuthState {
  const AuthState();
}

class LoadingState extends AuthState with AWSDebuggable {
  const LoadingState();

  AuthenticatorStep get step => AuthenticatorStep.loading;

  @override
  String get runtimeTypeName => 'LoadingState';
}

class AuthenticatedState extends AuthState with AWSDebuggable {
  const AuthenticatedState();

  @override
  String get runtimeTypeName => 'AuthenticatedState';
}

@immutable
class UnauthenticatedState extends AuthState
    with AWSEquatable<UnauthenticatedState>, AWSDebuggable {
  const UnauthenticatedState({required AuthenticatorStep step}) : _step = step;
  final AuthenticatorStep _step;

  AuthenticatorStep get step => _step;

  static const signUp = UnauthenticatedState(step: AuthenticatorStep.signUp);
  static const signIn = UnauthenticatedState(step: AuthenticatorStep.signIn);
  static const confirmSignUp =
      UnauthenticatedState(step: AuthenticatorStep.confirmSignUp);
  static const confirmSignInMfa =
      UnauthenticatedState(step: AuthenticatorStep.confirmSignInMfa);
  static const confirmSignInNewPassword =
      UnauthenticatedState(step: AuthenticatorStep.confirmSignInNewPassword);
  static const resetPassword =
      UnauthenticatedState(step: AuthenticatorStep.resetPassword);
  static const confirmResetPassword =
      UnauthenticatedState(step: AuthenticatorStep.confirmResetPassword);

  @override
  List<Object?> get props => [step];

  @override
  String get runtimeTypeName => 'UnauthenticatedState';
}

class AttributeVerificationSent extends UnauthenticatedState {
  const AttributeVerificationSent(this.userAttributeKey)
      : super(step: AuthenticatorStep.confirmVerifyUser);

  final CognitoUserAttributeKey userAttributeKey;

  @override
  List<Object?> get props => [step, userAttributeKey];

  @override
  String get runtimeTypeName => 'AttributeVerificationSent';
}

class VerifyUserFlow extends UnauthenticatedState {
  const VerifyUserFlow({required this.unverifiedAttributeKeys})
      : super(step: AuthenticatorStep.verifyUser);
  final List<CognitoUserAttributeKey> unverifiedAttributeKeys;

  @override
  List<Object?> get props => [step, unverifiedAttributeKeys];

  @override
  String get runtimeTypeName => 'VerifyUserFlow';
}

class ConfirmSignInCustom extends UnauthenticatedState {
  const ConfirmSignInCustom({
    this.publicParameters = const <String, String>{},
  }) : super(step: AuthenticatorStep.confirmSignInCustomAuth);
  final Map<String, String> publicParameters;

  @override
  List<Object?> get props => [step, publicParameters];

  @override
  String get runtimeTypeName => 'ConfirmSignInCustom';
}
